# -*- coding: utf-8 -*-
"""
Created on Fri Jan 10 14:00:59 2025

@author: mstep
"""

import tkinter as tk
from tkinter import messagebox
from tkinter import filedialog as fd
from PIL import Image, ImageTk

class LoadImageApp:
    def __init__(self):
        see_problem = False

        self.window = tk.Tk()

        # Use the following to see the highlight border more easily.
        if see_problem: self.window.configure(bg='lightblue')

        self.window.title('pil_load_image')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry('300x300')

        # Build the menu.
        self.build_menus()

        # Create the Canvas.
        if see_problem:
            # See the highlight border more easily.
            self.canvas = tk.Canvas(self.window, bg='white', width=10, height=10)
        else:
            # Set highlightthickness to prevent the Canvas from having a border.
            bg = self.window.cget('bg')
            self.canvas = tk.Canvas(self.window, bg=bg, width=10, height=10,
                borderwidth=0, highlightthickness=0)
        self.canvas.pack(side=tk.TOP, fill=tk.NONE, expand=False, anchor=tk.NW,
            padx=10, pady=10)

        # Display the window.
        self.window.focus_force()
        self.window.mainloop()

    def build_menus(self):
        '''Build the menu bar.'''
        menu_bar = tk.Menu(self.window)
        self.window.config(menu=menu_bar)
        self.build_file_menu(menu_bar)

    def build_file_menu(self, menu_bar):
        '''Build the File menu.'''
        file_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='File', menu=file_menu)

        # Note: You must save the photo image in a persistent
        # variable so tkinter can redraw it when needed.

        # Note: You need to include the compound parameter
        # if you want to use both images and text. That value
        # tells where to put the image relative to the text.

        # Open
        self.open_photo_image = ImageTk.PhotoImage(file='open.png')
        file_menu.add_command(label='Open Image...', accelerator='Ctrl+O',
            compound='left',
            command=self.mnu_open_image, image=self.open_photo_image)
        self.window.bind('<Control-o>', lambda event: self.mnu_open_image())

        # Note: If you don't include an image, the menu item doesn't
        # quite line up with items that do have an image. You can fix
        # it by including a blank image.

        file_menu.add_separator()

        # Exit
        self.exit_photo_image = ImageTk.PhotoImage(file='exit.png')
        file_menu.add_command(label='Exit', compound='left',
            command=self.mnu_exit, image=self.exit_photo_image)

    def mnu_open_image(self):
        self.pil_image = self.get_image_file('Load Image')
        self.show_image()

    def get_image_file(self, title):
        '''
        Let the user pick an image file.
        Then load and return it in an RGB PIL Image.
        '''
        filetypes = (
            ('Image Files', '*.png;*.jpg;*.bmp;*.gif;*.tif'),
            ('All files', '*.*')
        )
        filename = fd.askopenfilename(title=title, filetypes=filetypes)
        if not filename: return None

        try:
            return Image.open(filename)
        except Exception as e:
            messagebox.showinfo('Open Error', f'Error loading image file.\n{e}')
            return None

    def show_image(self):
        '''Display the image.'''
        if self.pil_image == None: return

        # Convert into a PhotoImage.
        self.photo_image = ImageTk.PhotoImage(self.pil_image)

        # Display it.
        self.canvas.delete(tk.ALL)
        self.canvas.create_image(0, 0, anchor=tk.NW, image=self.photo_image)
        wid = self.photo_image.width()
        hgt = self.photo_image.height()
        self.canvas.config(width=wid, height=hgt)

    def mnu_exit(self):
        print('Exit')
        self.kill_callback()

    def kill_callback(self):
        # Destroy the tkinter window.
        self.window.destroy()

# In[19]:
LoadImageApp()
print('Done')
